export P=ogdi
export V=4.1.0
export B=1
export MAINTAINER=JuergenFischer

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

[ -f ogdi_4_1_0.tar.gz ] || wget https://github.com/libogdi/ogdi/archive/ogdi_4_1_0.tar.gz
if ! [ -f ../makefile ]; then
	tar -C .. -xzf ogdi_4_1_0.tar.gz  --xform s,ogdi-ogdi_4_1_0,.,
	cp common.mak ../config
	patch -d .. -p0 <diff
fi

if ! [ -d "$OSGEO4W_REP" ]; then
	echo no repository
	exit 1
fi

fetchenv() {
	local IFS
	IFS=
	batch=$1
	shift

	if ! [ -f "$batch" ]; then
		echo "$batch not found"
		return 1
	fi

	srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
	dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
	diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
	envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
	cmd /c set >$srcenv
	cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
	/usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
	s/\\\\/\\//g;
	s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
	s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
	/usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
	. $diffenv
	PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
	rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in x86 x86_64; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT=/c/OSGeo4W
			export VCARCH=x86
			export TARGET=win32
			export TARGETFLAGS=
			export OVERRIDECOMMONMAK=no
			export ZLIB=zlib.lib
			export EXPAT=libexpat.lib
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
			export VCARCH=x64
			export TARGET=win64
			export TARGETFLAGS="/D_AMD64_=1"
			export OVERRIDECOMMONMAK=yes
			export ZLIB=zdll.lib
			export EXPAT=expat.lib
			;;

		*)
			echo invalid arch
			exit 1
			;;

		esac

		export R=$OSGEO4W_REP/$ARCH/release/$P
		mkdir -p $R/$P-devel

		cat <<EOF >$R/setup.hint
sdesc: "OGDI data access library (mainly for VPF reading)"
ldesc: "OGDI data access library (mainly for VPF reading)"
category: Libs
maintainer: $MAINTAINER
requires: expat zlib msvc2015
EOF

		cat <<EOF >$R/$P-devel/setup.hint
sdesc: "OGDI data access library (Development)"
ldesc: "OGDI data access library (Development)"
category: Libs
maintainer: $MAINTAINER
requires: ogdi
external-source: ogdi
EOF

		cp ../LICENSE $R/$P-$V-$B.txt
		cp ../LICENSE $R/$P-devel/$P-devel-$V-$B.txt

		fetchenv "$OSGEO4W_ROOT/bin/o4w_env.bat"
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH
		export PATH="/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE:/c/Program Files/CMake/bin:$PATH:/bin"

		cd ..

		make TOPDIR=$(cygpath -a -m $PWD) TARGET=$TARGET OVERRIDE_COMMON_MAK=$OVERRIDECOMMONMAK clean

		make TOPDIR=$(cygpath -a -m $PWD) TARGET=$TARGET OVERRIDE_COMMON_MAK=$OVERRIDECOMMONMAK \
			FG=release \
        	TARGET=$TARGET \
			CPP_RELEASE="/I$(cygpath -m $PWD/include/win32) $TARGETFLAGS /D_CRT_SECURE_NO_WARNINGS=1 /D_WINREG_=1 /DDUMMY_NAD_CVT" \
			ZLIB_SETTING=external ZLIB_INCLUDE="-I$(cygpath -m $OSGEO4W_ROOT/include)" ZLIB_LINKLIB="$(cygpath -m $OSGEO4W_ROOT/lib/$ZLIB)" \
			EXPAT_SETTING=external EXPAT_INCLUDE="-I$(cygpath -m $OSGEO4W_ROOT/include)" EXPAT_LINKLIB="$(cygpath -m $OSGEO4W_ROOT/lib/$EXPAT)"

		make TOPDIR=$(cygpath -a -m $PWD) TARGET=$TARGET OVERRIDE_COMMON_MAK=$OVERRIDECOMMONMAK \
			FG=release \
        	TARGET=$TARGET \
			CPP_RELEASE="/I$(cygpath -m $PWD/include/win32) $TARGETFLAGS /D_CRT_SECURE_NO_WARNINGS=1 /D_WINREG_=1 /DDUMMY_NAD_CVT" \
			ZLIB_SETTING=external ZLIB_INCLUDE="-I$(cygpath -m $OSGEO4W_ROOT/include)" ZLIB_LINKLIB="$(cygpath -m $OSGEO4W_ROOT/lib/$ZLIB)" \
			EXPAT_SETTING=external EXPAT_INCLUDE="-I$(cygpath -m $OSGEO4W_ROOT/include)" EXPAT_LINKLIB="$(cygpath -m $OSGEO4W_ROOT/lib/$EXPAT)" \
			install

		cd osgeo4w

		/bin/tar -cjf $R/$P-$V-$B.tar.bz2 \
			--absolute-names \
			--xform s,../bin/$TARGET,bin, \
			../bin/$TARGET/*.dll

		/bin/tar -cjf $R/$P-devel/$P-devel-$V-$B.tar.bz2 \
			--absolute-names \
			--xform s,install/include,include, \
			--xform s,../external/rpc_win32,include/ogdi, \
			--xform s,../lib/$TARGET,lib, \
			install/include \
			../external/rpc_win32/rpc \
			../lib/$TARGET/*.lib
			
		/bin/tar -C .. -cjf $R/$P-$V-$B-src.tar.bz2 osgeo4w/package.sh osgeo4w/common.mak osgeo4w/diff
	)
done

date
